.. _config-reference:

Avocado's Configuration Reference
=================================

This is current Avocado Configuration reference. You can adjust the values by two ways:

 - Configuration file options;
 - Command-line options (when available)

Some options that are used often are available for your convenience also at the command-line.
 This list has all options registered with Avocado so far.

.. note:: Please, keep in mind that we are in constant evolution and doing a
  huge improvements on how to configure Avocado, some options here can be changed
  in the near future.

.. include:: reference.rst
